Crate tree_sitter_owl_ms

Crate tree_sitter_owl_ms 

This crate provides owl-ms language support for the tree-sitter parsing library.

Typically, you will use the language function to add this language to a tree-sitter Parser, and then use the parser to parse some code:

let code = r#"
Ontology: Example
  Class: Person
"#;
let mut parser = tree_sitter_c2rust::Parser::new();
let language = tree_sitter_owl_ms::LANGUAGE;
parser
    .set_language(&language.into())
    .expect("Error loading owl_ms parser");
let tree = parser.parse(code, None).unwrap();
assert!(!tree.root_node().has_error());

Constants

FOLDS_QUERY
GRAMMAR
HIGHLIGHTS_QUERY
INDENTS_QUERY
LANGUAGE
The tree-sitter LanguageFn for this grammar.
NODE_TYPES
The content of the node-types.json file for this grammar.